struct CachedGalley {
last_used: u32,
children: Option<Arc<[u64]>>,
galley: Arc<Galley>,
}Fields
last_used: u32When it was last used
children: Option<Arc<[u64]>>Hashes of all other entries this one depends on for quick re-layout.
Their last_useds should be updated alongside this one to make sure they’re
not evicted.
galley: Arc<Galley>Auto Trait Implementations
impl Freeze for CachedGalley
impl RefUnwindSafe for CachedGalley
impl Send for CachedGalley
impl Sync for CachedGalley
impl Unpin for CachedGalley
impl UnsafeUnpin for CachedGalley
impl UnwindSafe for CachedGalley